# Integration of Pyperplan with the Unified Planning Library

This is the integrator for the [pyperplan](https://github.com/aibasel/pyperplan) planning system, a classical planner based on different search heuristics. Pyperplan supports action based problems with hierarchical typing.

You can install this engine as an extra requirement of the `unified-planning` package: `pip install unified-planning[pyperplan]`.
The installation has been tested on the latest versions of ubuntu, windows and macos.

**Default configuration:** BFS search.

**Planning approaches of UP supported:** classical planning.

**Operative modes of UP currently supported:** oneshot planning, grounding compilation.
